Index: chrome/browser/ui/page_info/page_info_ui.h |
diff --git a/chrome/browser/ui/page_info/website_settings_ui.h b/chrome/browser/ui/page_info/page_info_ui.h |
similarity index 84% |
rename from chrome/browser/ui/page_info/website_settings_ui.h |
rename to chrome/browser/ui/page_info/page_info_ui.h |
index 2061229f7cd0709782efc768f924fd572cb0a859..e1d47caafdda24f1c21fda1f324193e8539575e4 100644 |
--- a/chrome/browser/ui/page_info/website_settings_ui.h |
+++ b/chrome/browser/ui/page_info/page_info_ui.h |
@@ -2,21 +2,21 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef CHROME_BROWSER_UI_PAGE_INFO_WEBSITE_SETTINGS_UI_H_ |
-#define CHROME_BROWSER_UI_PAGE_INFO_WEBSITE_SETTINGS_UI_H_ |
+#ifndef CHROME_BROWSER_UI_PAGE_INFO_PAGE_INFO_UI_H_ |
+#define CHROME_BROWSER_UI_PAGE_INFO_PAGE_INFO_UI_H_ |
#include <memory> |
#include <string> |
#include <vector> |
#include "base/strings/string16.h" |
-#include "chrome/browser/ui/page_info/website_settings.h" |
+#include "chrome/browser/ui/page_info/page_info.h" |
#include "components/content_settings/core/common/content_settings.h" |
#include "components/content_settings/core/common/content_settings_types.h" |
#include "ui/gfx/native_widget_types.h" |
class Profile; |
-class WebsiteSettings; |
+class PageInfo; |
namespace gfx { |
class Image; |
@@ -26,15 +26,15 @@ namespace net { |
class X509Certificate; |
} |
// The class |WebsiteSettingsUI| specifies the platform independent |
// interface of the website settings UI. The website settings UI displays |
// information and controls for site specific data (local stored objects like |
// cookies), site specific permissions (location, popup, plugin, etc. |
// permissions) and site specific information (identity, connection status, |
// etc.). |
-class WebsiteSettingsUI { |
+class PageInfoUI { |
public: |
// The Website Settings UI contains several tabs. Each tab is associated with |
// a unique tab id. The enum |TabId| contains all the ids for the tabs. |
enum TabId { |
TAB_ID_PERMISSIONS = 0, |
@@ -89,11 +89,11 @@ class WebsiteSettingsUI { |
// |ChosenObjectInfo| contains information about a single |object| of a |
// chooser |type| that the current website has been granted access to. |
struct ChosenObjectInfo { |
- ChosenObjectInfo(const WebsiteSettings::ChooserUIInfo& ui_info, |
+ ChosenObjectInfo(const PageInfo::ChooserUIInfo& ui_info, |
std::unique_ptr<base::DictionaryValue> object); |
~ChosenObjectInfo(); |
// |ui_info| for this chosen object type. |
- const WebsiteSettings::ChooserUIInfo& ui_info; |
+ const PageInfo::ChooserUIInfo& ui_info; |
// The opaque |object| representing the thing the user selected. |
std::unique_ptr<base::DictionaryValue> object; |
}; |
@@ -109,7 +109,7 @@ class WebsiteSettingsUI { |
// sites. |
std::string site_identity; |
// Status of the site's identity. |
- WebsiteSettings::SiteIdentityStatus identity_status; |
+ PageInfo::SiteIdentityStatus identity_status; |
// Helper to get security description info to display to the user. |
std::unique_ptr<SecurityDescription> GetSecurityDescription() const; |
// Textual description of the site's identity status that is displayed to |
@@ -118,7 +118,7 @@ class WebsiteSettingsUI { |
// The server certificate if a secure connection. |
scoped_refptr<net::X509Certificate> certificate; |
// Status of the site's connection. |
- WebsiteSettings::SiteConnectionStatus connection_status; |
+ PageInfo::SiteConnectionStatus connection_status; |
// Textual description of the site's connection status that is displayed to |
// the user. |
std::string connection_status_description; |
@@ -134,7 +134,7 @@ class WebsiteSettingsUI { |
using PermissionInfoList = std::vector<PermissionInfo>; |
using ChosenObjectInfoList = std::vector<std::unique_ptr<ChosenObjectInfo>>; |
- virtual ~WebsiteSettingsUI(); |
+ virtual ~PageInfoUI(); |
// Returns the UI string for the given permission |type|. |
static base::string16 PermissionTypeToUIString(ContentSettingsType type); |
@@ -172,18 +172,17 @@ class WebsiteSettingsUI { |
bool deleted); |
// Returns the identity icon ID for the given identity |status|. |
- static int GetIdentityIconID(WebsiteSettings::SiteIdentityStatus status); |
+ static int GetIdentityIconID(PageInfo::SiteIdentityStatus status); |
// Returns the identity icon for the given identity |status|. |
- static const gfx::Image& GetIdentityIcon( |
- WebsiteSettings::SiteIdentityStatus status); |
+ static const gfx::Image& GetIdentityIcon(PageInfo::SiteIdentityStatus status); |
// Returns the connection icon ID for the given connection |status|. |
- static int GetConnectionIconID(WebsiteSettings::SiteConnectionStatus status); |
+ static int GetConnectionIconID(PageInfo::SiteConnectionStatus status); |
// Returns the connection icon for the given connection |status|. |
static const gfx::Image& GetConnectionIcon( |
- WebsiteSettings::SiteConnectionStatus status); |
+ PageInfo::SiteConnectionStatus status); |
// Sets cookie information. |
virtual void SetCookieInfo(const CookieInfoList& cookie_info_list) = 0; |
@@ -197,8 +196,8 @@ class WebsiteSettingsUI { |
virtual void SetIdentityInfo(const IdentityInfo& identity_info) = 0; |
}; |
-typedef WebsiteSettingsUI::CookieInfoList CookieInfoList; |
-typedef WebsiteSettingsUI::PermissionInfoList PermissionInfoList; |
-typedef WebsiteSettingsUI::ChosenObjectInfoList ChosenObjectInfoList; |
+typedef PageInfoUI::CookieInfoList CookieInfoList; |
+typedef PageInfoUI::PermissionInfoList PermissionInfoList; |
+typedef PageInfoUI::ChosenObjectInfoList ChosenObjectInfoList; |
-#endif // CHROME_BROWSER_UI_PAGE_INFO_WEBSITE_SETTINGS_UI_H_ |
+#endif // CHROME_BROWSER_UI_PAGE_INFO_PAGE_INFO_UI_H_ |
@@ -26,15 +26,15 @@ namespace net { |
class X509Certificate; |
} |
-// The class |WebsiteSettingsUI| specifies the platform independent |
-// interface of the website settings UI. The website settings UI displays |
+// The class |PageInfoUI| specifies the platform independent |
+// interface of the page info UI. The page info UI displays |
// information and controls for site specific data (local stored objects like |
// cookies), site specific permissions (location, popup, plugin, etc. |
@@ -26,15 +26,15 @@ namespace net { |
public: |
- // The Website Settings UI contains several tabs. Each tab is associated with |
+ // The Page Info UI contains several tabs. Each tab is associated with |
// a unique tab id. The enum |TabId| contains all the ids for the tabs. |
enum TabId { |